@@ -6,47 +6,25 @@
  */
 
 #include "groupingcontainment.h"
-#include "debug.h"
 
 #include <QDebug>
-#include <QProcess>
-
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
-#include <QDBusPendingCallWatcher>
 #include <QMenu>
 #include <QQuickItem>
 #include <QQuickWindow>
 #include <QScreen>
 #include <QStandardItemModel>
 
-#include <Plasma/PluginLoader>
-#include <Plasma/ServiceJob>
-
-#include <KActionCollection>
-#include <KLocalizedString>
-
-#include <plasma_version.h>
+#include <KActionCollection> // Applet::actions
 
 GroupingContainment::GroupingContainment(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Containment(parent, data, args)
 {
     setHasConfigurationInterface(true);
-    setContainmentType(Plasma::Types::CustomEmbeddedContainment);
-}
-
-GroupingContainment::~GroupingContainment()
-{
-}
-
-void GroupingContainment::init()
-{
-    Containment::init();
 }
 
 void GroupingContainment::newTask(const QString &task)
 {
-    createApplet(task, QVariantList() << QStringLiteral("org.kde.plasma:force-create"));
+    createApplet(task, QVariantList{QStringLiteral("org.kde.plasma:force-create")});
 }
 
 void GroupingContainment::cleanupTask(const QString &task)
@@ -88,7 +66,7 @@ void GroupingContainment::showPlasmoidMenu(QQuickItem *appletInterface, int x, i
     }
 
     // add run associated action/ remove / alternatives
-    desktopMenu->addActions(applet->actions()->actions());
+    desktopMenu->addActions(applet->internalActions());
 
     if (desktopMenu->isEmpty()) {
         delete desktopMenu;
